embassy-crypto

Crates

git

Versions

default

Flavors

ChaCha8Poly1305

Struct ChaCha8Poly1305 

pub struct ChaCha8Poly1305 { /* private fields */ }
ChaCha8-Poly1305: ChaCha20-Poly1305 with the 8-round ChaCha8 in place of ChaCha20.

Authenticated encryption with a 256-bit key, a 96-bit nonce and a 128-bit tag. The nonce must never repeat for a given key.

Implementations

Source

impl ChaCha8Poly1305

pub const KEY_SIZE: usize = 32

Size of the key, in bytes.

pub const NONCE_SIZE: usize = 12

Size of the nonce, in bytes.

pub const TAG_SIZE: usize = 16

Size of the tag, in bytes.

pub fn new(key: &[u8; 32]) -> Self

Initialize with key.

pub fn encrypt( &self, nonce: &[u8; 12], aad: &[u8], buf: &mut [u8], ) -> Result<[u8; 16], Error>

Encrypt buf in place, authenticating it and aad, and return the tag.

pub fn encrypt_to( &self, nonce: &[u8; 12], aad: &[u8], input: &[u8], output: &mut [u8], ) -> Result<[u8; 16], Error>

Encrypt input to output, authenticating it and aad, and return the tag.

pub fn decrypt( &self, nonce: &[u8; 12], aad: &[u8], buf: &mut [u8], tag: &[u8; 16], ) -> Result<(), Error>

Verify tag over buf and aad, then decrypt buf in place.

On Error::InvalidSignature the contents of buf are unspecified.

pub fn decrypt_to( &self, nonce: &[u8; 12], aad: &[u8], input: &[u8], output: &mut [u8], tag: &[u8; 16], ) -> Result<(), Error>

Verify tag over input and aad, then decrypt input to output.

On Error::InvalidSignature the contents of output are unspecified.